% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pollroseMap.R
\name{pollroseMap}
\alias{pollroseMap}
\title{Pollution rose plots on interactive leaflet maps}
\usage{
pollroseMap(
  data,
  pollutant = "nox",
  statistic = "prop.count",
  latitude = "lat",
  longitude = "lon",
  provider = "OpenStreetMap",
  type = "default",
  cols = "jet",
  alpha = 1,
  key = FALSE,
  iconWidth = 200,
  iconHeight = 200,
  fig.width = 4,
  fig.height = 4,
  ...
)
}
\arguments{
\item{data}{A data frame. The data frame must contain the data to plot a
\code{\link[openair:windRose]{openair::pollutionRose()}}, which includes wind speed (\code{ws}), wind direction
(\code{wd}), and the column representing the
concentration of a pollutant. In addition, \code{data} must include a
decimal latitude and longitude.}

\item{pollutant}{The column name(s) of the pollutant(s) to plot. If multiple
pollutants are specified, they can be toggled between using a "layer
control" interface.}

\item{statistic}{The \code{statistic} to be applied to each data
bin in the plot. Options currently include \dQuote{prop.count},
\dQuote{prop.mean} and \dQuote{abs.count}. The default
\dQuote{prop.count} sizes bins according to the proportion of
the frequency of measurements.  Similarly, \dQuote{prop.mean}
sizes bins according to their relative contribution to the mean.
\dQuote{abs.count} provides the absolute count of measurements
in each bin.}

\item{latitude}{The decimal latitude.}

\item{longitude}{The decimal longitude.}

\item{provider}{The base map(s) to be used. See
\url{http://leaflet-extras.github.io/leaflet-providers/preview/} for a list
of all base maps that can be used. If multiple base maps are provided, they
can be toggled between using a "layer control" interface.}

\item{type}{The grouping variable that provides a data set for a specific
location. Often, with several sites, \code{type = "site"} is used.}

\item{cols}{The colours used for plotting.}

\item{alpha}{The alpha transparency to use for the plotting surface (a value
between 0 and 1 with zero being fully transparent and 1 fully opaque).}

\item{key}{Should the key of the plot be drawn. Default is \code{FALSE}.}

\item{iconWidth}{The actual width of the plot on the map in pixels.}

\item{iconHeight}{The actual height of the plot on the map in pixels.}

\item{fig.width}{The width of the plots to be produced in inches.}

\item{fig.height}{The height of the plots to be produced in inches.}

\item{...}{Other arguments for \code{\link[openair:windRose]{openair::pollutionRose()}}.}
}
\value{
A leaflet object.
}
\description{
Pollution rose plots on interactive leaflet maps
}
\examples{
\dontrun{
pollroseMap(polar_data,
  statistic = "prop.count",
  type = "site",
  provider = "Stamen.Toner"
)
}
}
